from setuptools import setup

setup(name='apex_stats',
      version='0.1',
      description='Tracker.gg api wrapper',
      url='http://github.com/yamozha/apex-stats',
      author='yamozha',
      author_email='yamozha16@protonmail.ch',
      license='MIT',
      packages=['apex_stats'],
      zip_safe=False)